@@ -35,13 +35,17 @@ class ForecasterParalleLauncher():
         self.key_args.sort()
         self.counter = 1
         for me_arg in self.key_args:
-            continuous_saving_key, two_states_saving_key, three_states_saving_key = self.create_saving_key(*me_arg)
+            continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo = self.create_saving_key(*me_arg)
             self.mapping_keys[continuous_saving_key] = self.counter
             self.counter = self.counter + 1
             self.mapping_keys[two_states_saving_key] = self.counter
             self.counter = self.counter + 1
+            self.mapping_keys[two_states_saving_key_lo] = self.counter
+            self.counter = self.counter + 1
             self.mapping_keys[three_states_saving_key] = self.counter
             self.counter = self.counter + 1
+            self.mapping_keys[three_states_saving_key_lo] = self.counter
+            self.counter = self.counter + 1
 
         self.run_number = self.counter - 1
         self.local_root_directory = local_root_directory
@@ -70,24 +74,42 @@ class ForecasterParalleLauncher():
             's_eval':s_eval,
             'calibration_step':calibration_step,
             'signal_type' : signal_type,
-            'discretization':0
+            'discretization':0,
+            'type': 'continuous'
         }
         common_params.update(idios)
         continuous_saving_key = json.dumps(common_params, sort_keys=True)
         continuous_saving_key = signal_utility.convert_to_sql_column_format(continuous_saving_key)
 
         common_params.update({
-            'discretization':2
+            'discretization':2,
+            'type': 'long short'
         })
         two_states_saving_key = json.dumps(common_params, sort_keys=True)
         two_states_saving_key = signal_utility.convert_to_sql_column_format(two_states_saving_key)
 
         common_params.update({
-            'discretization':3
+            'discretization': 2,
+            'type': 'long only'
+        })
+        two_states_saving_key_lo = json.dumps(common_params, sort_keys=True)
+        two_states_saving_key_lo = signal_utility.convert_to_sql_column_format(two_states_saving_key_lo)
+
+        common_params.update({
+            'discretization':3,
+            'type': 'long short'
         })
         three_states_saving_key = json.dumps(common_params, sort_keys=True)
         three_states_saving_key = signal_utility.convert_to_sql_column_format(three_states_saving_key)
-        return continuous_saving_key, two_states_saving_key, three_states_saving_key
+
+        common_params.update({
+            'discretization': 3,
+            'type': 'long only'
+        })
+        three_states_saving_key_lo = json.dumps(common_params, sort_keys=True)
+        three_states_saving_key_lo = signal_utility.convert_to_sql_column_format(three_states_saving_key_lo)
+
+        return continuous_saving_key, two_states_saving_key, three_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo
 
     def launchParallelPool(self, toRun, use_num_cpu):
         with Pool(processes=use_num_cpu) as pool:
