@@ -53,8 +53,11 @@ def pair_handling_message(fetcher, msg, compute_signal=True, compute_parallel =
             minute_dt_object = datetime.utcfromtimestamp(key_ts)
             minute_name = fetcher.pair + '_' + minute_dt_object.strftime('%d_%b_%Y_%H_%M')
             print('appending one minute row '+minute_name)
-            new_data_lst = [key_ts, fetcher.pair, open_dict[key_ts], high_dict[key_ts], low_dict[key_ts], close_dict[key_ts], volu_dict[key_ts]]
+
+            new_data_lst = [key_ts, open_dict[key_ts], high_dict[key_ts], low_dict[key_ts],
+                            close_dict[key_ts], volu_dict[key_ts]]
             new_data = np.array(new_data_lst)
+
             print(new_data)
             if fetcher.minute_np is None:
                 fetcher.minute_np = new_data
@@ -106,7 +109,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         self.client = Client(BINANCE_PUBLIC, BINANCE_SECRET)
         self.aws_client = napoleon_s3_connector.NapoleonS3Connector(AWS_PUBLIC,AWS_SECRET,region=AWS_REGION)
         self.pair = pair
-        self.minute_columns = ['ts','pair','open', 'high', 'low', 'close', 'volumefrom']
+        self.minute_columns = ['ts', 'open', 'high', 'low', 'close', 'volumefrom']
         self.minute_df = pd.DataFrame(columns=self.minute_columns)
         self.minute_np = None
         self.signal_np = None
@@ -147,7 +150,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
             params = json.loads(run_json_string)
             salty = str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
             params = json.loads(run_json_string)
-            readable_label = params['signal_type'] + str(params['transaction_costs']) + str(params['normalization']) + salty
+            readable_label = params['signal_type'] + str(params['trigger']) + salty
             self.signal_mapping[me_signal]=readable_label
             if params['lookback_window']>max_lookback_window:
                 max_lookback_window=params['lookback_window']
@@ -168,23 +171,23 @@ class RealTimeSignalEnsemblingParalleLauncher():
         self.last_minute = None
 
 
-    def get_aws_last24_passed_full_hours(self):
+    def get_aws_last_passed_full_hours(self, nb_last_hours = 24):
         date_now = datetime.utcnow()
         files_to_fetch = []
         #minute_name = self.pair + '_' + date_now.strftime('%d_%b_%Y_%H_%M')
         #files_to_fetch.append(minute_name)
         d = date_now
-        for i in range(24):
+        for i in range(nb_last_hours):
             d = d - timedelta(hours=1)
             minute_name = self.pair + '_' + d.strftime('%d_%b_%Y_%H')
             files_to_fetch.append(minute_name)
         aggregated_df = None
         for me_file in files_to_fetch:
-
             df = None
             try:
                 df = self.aws_client.download_dataframe_from_csv(self.bucket, me_file)
-                df = df.drop(columns=['Unnamed: 0'])
+                df = aggregated_df.df(by=['date'])
+                df_test = df.pivot_table(index=['date'], aggfunc='size')
             except Exception as e:
                 print(e)
                 df = None
@@ -195,6 +198,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
                     aggregated_df = pd.concat([aggregated_df, df])
             if aggregated_df is None:
                 if df is not None:
+                    print(df.shape)
                     aggregated_df = df
 
         return aggregated_df
@@ -221,9 +225,6 @@ class RealTimeSignalEnsemblingParalleLauncher():
             updated_df=pd.DataFrame(data=self.minute_np, columns = self.minute_columns, index=range(len(self.minute_np)))
         else:
             updated_df=pd.DataFrame(data=self.minute_np.reshape(1,len(self.minute_np)), columns = self.minute_columns, index=[0])
-        updated_df = updated_df.astype(
-            {'ts': 'float32', 'open': 'float32', 'high': 'float32', 'low': 'float32', 'close': 'float32',
-             'volumefrom': 'float32'})
         updated_df['ts'] = updated_df['ts'].astype(int)
         updated_df['ts'] = pd.to_datetime(updated_df['ts'], unit='s')
         updated_df = updated_df.sort_values(by=['ts'])
@@ -238,7 +239,9 @@ class RealTimeSignalEnsemblingParalleLauncher():
         signal_columns = [self.signal_mapping[me_sig] for me_sig in self.signals_list]
         me_columns = self.minute_columns + signal_columns
         updated_df=pd.DataFrame(data=self.signal_np, columns = me_columns, index=range(len(self.signal_np)))
-        updated_df = updated_df.astype({'ts': 'float32','open': 'float32', 'high': 'float32', 'low': 'float32', 'close': 'float32', 'volumefrom': 'float32'})
+        # updated_df = updated_df.astype(
+        #     {'ts': 'float64', 'open': 'float64', 'high': 'float64', 'low': 'float64', 'close': 'float64','volumefrom': 'float64'}
+        #                                )
         updated_df['ts']=updated_df['ts'].astype(int)
         updated_df['hour_ts'] = updated_df['ts']-updated_df['ts']%3600
         updated_df = updated_df.astype({'hour_ts': 'int32'})
@@ -247,7 +250,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         hour_timestamp = updated_df['hour_ts'].max()
         hour_dt_object = datetime.utcfromtimestamp(hour_timestamp)
         filename = self.pair+'_'+hour_dt_object.strftime('%d_%b_%Y_%H') #str(hourr_timestamp)
-        updated_df['ts'] = pd.to_datetime(updated_df['ts'], unit='s')
+        updated_df['ts'] = pd.to_datetime(updated_df['ts'], unit='m')
         updated_df = updated_df.sort_values(by=['ts'])
         updated_df = updated_df.rename(columns={"ts": "date"}, errors="raise")
         updated_df = updated_df.set_index(updated_df['date'])
@@ -260,7 +263,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
     def upload_last_hour_60_minutes_dataframe(self):
         print('updating minute df')
         updated_df=pd.DataFrame(data=self.minute_np, columns = self.minute_columns, index=range(len(self.minute_np)))
-        updated_df = updated_df.astype({'ts': 'float32','open': 'float32', 'high': 'float32', 'low': 'float32', 'close': 'float32', 'volumefrom': 'float32'})
+        #updated_df = updated_df.astype({'ts': 'float32','open': 'float32', 'high': 'float32', 'low': 'float32', 'close': 'float32', 'volumefrom': 'float32'})
         updated_df['ts']=updated_df['ts'].astype(int)
         updated_df['hour_ts'] = updated_df['ts']-updated_df['ts']%3600
         updated_df = updated_df.astype({'hour_ts': 'int32'})
@@ -326,15 +329,9 @@ class RealTimeSignalEnsemblingParalleLauncher():
         if normalization and not signal_generator.is_signal_continuum(signal_type):
             return
         lookback_window = params['lookback_window']
-
-
         if lookback_window>self.minute_df.shape[0]:
             return np.nan
-        print('incoming data')
-
         freqly = self.minute_df.iloc[-lookback_window:,:].copy()
-        freqly = freqly.drop(columns=['pair'])
-
         signal_generation_method_to_call = getattr(signal_generator, signal_type)
         last_generated_signal = signal_utility.compute_last_signal(freqly, lookback_window,
                                                                    lambda x: signal_generation_method_to_call(
