@@ -30,7 +30,7 @@ def weights_shift(weight_mat=None, trading_delay = 1):
     weight_mat = weight_mat.shift(trading_delay)
     return weight_mat, last_predicted_weights
 
-def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=None, weight_cutting_rate = 0.7, normalize = True , display=False, max_iteration = 50, trading_delay=1, display_slices = True):
+def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=None, weight_cutting_rate = 0.7, normalize = True , display=False, max_iteration = 50, trading_delay=1, display_slices = False):
     """ Process weight to respect constraints.
     Parameters
     ----------
@@ -50,7 +50,10 @@ def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=No
 
     def cut_process(series):
         # True if less than 50% of obs. are constant
-        return series.value_counts(dropna=False).max() < weight_cutting_rate * len(series)
+        if len(series)>int(s/2):
+            return series.value_counts(dropna=False).max() < weight_cutting_rate * len(series)
+        else:
+            return True
 
     previousValidWeights = None
     for t in range(n, T, s):
